@@ -31,6 +31,7 @@
 #include <kdbusconnectionpool.h>
 #include <itemfetchscope.h>
 #include <mailtransport/sentactionattribute.h>
+#include <mailtransport/sentbehaviourattribute.h>
 
 #include <knotifyconfigwidget.h>
 #include "maildispatcher_debug.h"
@@ -60,6 +61,7 @@ public:
           sendingInProgress(false),
           sentAnything(false),
           errorOccurred(false),
+          showSentNotification(true),
           sentItemsSize(0),
           sentActionHandler(Q_NULLPTR)
     {
@@ -78,6 +80,7 @@ public:
     bool sendingInProgress;
     bool sentAnything;
     bool errorOccurred;
+    bool showSentNotification;
     qulonglong sentItemsSize;
     SentActionHandler *sentActionHandler;
 
@@ -152,13 +155,14 @@ void MailDispatcherAgent::Private::dispatch()
                 Q_EMIT q->percent(100);
                 Q_EMIT q->status(AgentBase::Idle, i18n("Finished sending messages."));
 
-                if (!errorOccurred) {
+                if (!errorOccurred && showSentNotification) {
                     KNotification *notify = new KNotification(QStringLiteral("emailsent"));
                     notify->setComponentName(QStringLiteral("akonadi_maildispatcher_agent"));
                     notify->setTitle(i18nc("Notification title when email was sent", "E-Mail Successfully Sent"));
                     notify->setText(i18nc("Notification when the email was sent", "Your E-Mail has been sent successfully."));
                     notify->sendEvent();
                 }
+                showSentNotification = true;
             } else {
                 // Empty queue.
                 Q_EMIT q->status(AgentBase::Idle, i18n("No items in queue."));
@@ -179,9 +183,6 @@ MailDispatcherAgent::MailDispatcherAgent(const QString &id)
     migrate.migrate();
 
     qCDebug(MAILDISPATCHER_LOG) << "maildispatcheragent: At your service, sir!";
-#ifdef KDEPIM_STATIC_LIBS
-    ___MailTransport____INIT();
-#endif
 
     new SettingsAdaptor(Settings::self());
     new MailDispatcherAgentAdaptor(this);
@@ -339,6 +340,12 @@ void MailDispatcherAgent::Private::sendResult(KJob *job)
                 sentActionHandler->runAction(action);
             }
         }
+        const auto bhAttribute = sentItem.attribute<MailTransport::SentBehaviourAttribute>();
+        if (bhAttribute) {
+            showSentNotification = !bhAttribute->sendSilently();
+        } else {
+            showSentNotification = true;
+        }
     }
 
     // dispatch next message
