@@ -49,35 +49,29 @@ InfoDialog::InfoDialog(bool closeWhenDone) :
     mAutoScrollList(true)
 {
     setAttribute(Qt::WA_DeleteOnClose);
+    QVBoxLayout *mainLayout = new QVBoxLayout(this);
 
-    mButtonBox = new QDialogButtonBox(QDialogButtonBox::Close);
-    QVBoxLayout *mainLayout = new QVBoxLayout;
-    setLayout(mainLayout);
-    connect(mButtonBox, &QDialogButtonBox::accepted, this, &InfoDialog::accept);
-    connect(mButtonBox, &QDialogButtonBox::rejected, this, &InfoDialog::reject);
-    mButtonBox->button(QDialogButtonBox::Close)->setEnabled(false);
-
-    QWidget *widget = new QWidget(this);
-    QVBoxLayout *widgetLayout = new QVBoxLayout(widget);
-
-    mList = new QListWidget(widget);
+    mList = new QListWidget(this);
     mList->setMinimumWidth(640);
-    widgetLayout->addWidget(mList);
+    mainLayout->addWidget(mList);
 
     QHBoxLayout *statusLayout = new QHBoxLayout;
-    widgetLayout->addLayout(statusLayout);
+    mainLayout->addLayout(statusLayout);
 
-    mStatusLabel = new QLabel(widget);
+    mStatusLabel = new QLabel(this);
     mStatusLabel->setSizePolicy(QSizePolicy::MinimumExpanding, QSizePolicy::Preferred);
     statusLayout->addWidget(mStatusLabel);
 
-    mProgressBar = new QProgressBar(widget);
+    mProgressBar = new QProgressBar(this);
     mProgressBar->setSizePolicy(QSizePolicy::Maximum, QSizePolicy::Preferred);
     mProgressBar->setMinimumWidth(200);
     statusLayout->addWidget(mProgressBar);
-    mainLayout->addWidget(widget);
-    mainLayout->addWidget(mButtonBox);
 
+    mButtonBox = new QDialogButtonBox(QDialogButtonBox::Close, this);
+    connect(mButtonBox, &QDialogButtonBox::accepted, this, &InfoDialog::accept);
+    connect(mButtonBox, &QDialogButtonBox::rejected, this, &InfoDialog::reject);
+    mButtonBox->button(QDialogButtonBox::Close)->setEnabled(false);
+    mainLayout->addWidget(mButtonBox);
 }
 
 InfoDialog::~InfoDialog()
