@@ -25,14 +25,13 @@
 
 #include "imapidlemanager.h"
 
-#include "imapresource_debug.h"
 #include "imapresource_debug.h"
 
 #include <kimap/idlejob.h>
 #include <kimap/selectjob.h>
 #include <kimap/session.h>
 
-#include <QtCore/QTimer>
+#include <QTimer>
 
 #include "imapresource.h"
 #include "sessionpool.h"
@@ -169,7 +168,7 @@ void ImapIdleManager::onStatsReceived(KIMAP::IdleJob *job, const QString &mailBo
 
 void ImapIdleManager::onFlagsChanged(KIMAP::IdleJob *job)
 {
+    Q_UNUSED(job);
     qCDebug(IMAPRESOURCE_LOG) << "IDLE flags changed in" << m_session->selectedMailBox();
     m_resource->synchronizeCollection(m_state->collection().id());
 }
-
