@@ -20,18 +20,18 @@
 #ifndef UIDNEXTATTRIBUTE_H
 #define UIDNEXTATTRIBUTE_H
 
-#include <akonadi/attribute.h>
+#include <attribute.h>
 
 class UidNextAttribute : public Akonadi::Attribute
 {
 public:
-    explicit UidNextAttribute( int uidnext = 0 );
-    void setUidNext( int uidnext );
+    explicit UidNextAttribute(int uidnext = 0);
+    void setUidNext(int uidnext);
     int uidNext() const;
-    virtual QByteArray type() const;
-    virtual Attribute* clone() const;
-    virtual QByteArray serialized() const;
-    virtual void deserialize( const QByteArray &data );
+    QByteArray type() const Q_DECL_OVERRIDE;
+    Attribute *clone() const Q_DECL_OVERRIDE;
+    QByteArray serialized() const Q_DECL_OVERRIDE;
+    void deserialize(const QByteArray &data) Q_DECL_OVERRIDE;
 
 private:
     int mUidNext;
