@@ -29,10 +29,10 @@ class KolabChangeTagTask : public KolabRelationResourceTask
 {
     Q_OBJECT
 public:
-    explicit KolabChangeTagTask(ResourceStateInterface::Ptr resource, QSharedPointer<TagConverter> tagConverter, QObject *parent = Q_NULLPTR);
+    explicit KolabChangeTagTask(const ResourceStateInterface::Ptr &resource, const QSharedPointer<TagConverter> &tagConverter, QObject *parent = Q_NULLPTR);
 
 protected:
-    virtual void startRelationTask(KIMAP::Session *session);
+    void startRelationTask(KIMAP::Session *session) Q_DECL_OVERRIDE;
 
 private:
     KIMAP::Session *mSession;
