@@ -39,15 +39,14 @@ ConfigDialog::ConfigDialog(MaildirSettings *settings, const QString &identifier,
 {
     setWindowTitle(i18n("Select a MailDir folder"));
     QWidget *mainWidget = new QWidget(this);
-    QVBoxLayout *mainLayout = new QVBoxLayout;
-    setLayout(mainLayout);
+    QVBoxLayout *mainLayout = new QVBoxLayout(this);
     mainLayout->addWidget(mainWidget);
     ui.setupUi(mainWidget);
-    mFolderArchiveSettingPage = new FolderArchiveSettingPage(identifier);
+    mFolderArchiveSettingPage = new FolderArchiveSettingPage(identifier, this);
     mFolderArchiveSettingPage->loadSettings();
     ui.tabWidget->addTab(mFolderArchiveSettingPage, i18n("Archive Folder"));
 
-    QDialogButtonBox *buttonBox = new QDialogButtonBox(QDialogButtonBox::Ok | QDialogButtonBox::Cancel);
+    QDialogButtonBox *buttonBox = new QDialogButtonBox(QDialogButtonBox::Ok | QDialogButtonBox::Cancel, this);
     mOkButton = buttonBox->button(QDialogButtonBox::Ok);
     mOkButton->setDefault(true);
     mOkButton->setShortcut(Qt::CTRL | Qt::Key_Return);
