@@ -53,7 +53,7 @@ POP3Resource::POP3Resource(const QString &id)
       mIntervalTimer(new QTimer(this)),
       mTestLocalInbox(false),
       mWallet(Q_NULLPTR),
-      idsToSaveValid(false),
+      mIdsToSaveValid(false),
       mDeleteJob(Q_NULLPTR)
 {
     Akonadi::AttributeFactory::registerAttribute<Akonadi::Pop3ResourceAttribute>();
@@ -144,9 +144,8 @@ bool POP3Resource::retrieveItem(const Akonadi::Item &item, const QSet<QByteArray
 
 QString POP3Resource::buildLabelForPasswordDialog(const QString &detailedError) const
 {
-    QString queryText = i18n("Please enter the username and password for account '%1'.",
-                             agentName());
-    queryText += QLatin1String("<br>") + detailedError;
+    const QString queryText = i18n("Please enter the username and password for account '%1'.",
+                             agentName()) + QLatin1String("<br>") + detailedError;
     return queryText;
 }
 
@@ -169,7 +168,7 @@ void POP3Resource::walletOpenedForLoading(bool success)
     mWallet = Q_NULLPTR;
 
     if (!passwordLoaded) {
-        QString queryText = buildLabelForPasswordDialog(
+        const QString queryText = buildLabelForPasswordDialog(
                                 i18n("You are asked here because the password could not be loaded from the wallet."));
         showPasswordDialog(queryText);
     } else {
@@ -376,14 +375,14 @@ void POP3Resource::doStateStep()
 
             fetchJob->start();
         } else {
-            advanceState(Save);
+            advanceState(CheckRemovingMessage);
         }
     }
     break;
     case Save: {
         qCDebug(POP3RESOURCE_LOG) << "================ Starting state Save ===========================";
         qCDebug(POP3RESOURCE_LOG) << mPendingCreateJobs.size() << "item create jobs are pending";
-        if (mPendingCreateJobs.size() > 0) {
+        if (!mPendingCreateJobs.isEmpty()) {
             Q_EMIT status(Running, i18n("Saving downloaded messages."));
         }
 
@@ -416,6 +415,28 @@ void POP3Resource::doStateStep()
         }
         break;
     }
+    case CheckRemovingMessage: {
+        checkRemovingMessageFromServer();
+        break;
+    }
+
+    }
+}
+
+void POP3Resource::checkRemovingMessageFromServer()
+{
+    const QList<int> idToDeleteMessage = shouldDeleteId(-1);
+    if (!idToDeleteMessage.isEmpty()) {
+        mIdsWaitingToDelete << idToDeleteMessage;
+        if (!mDeleteJob) {
+            mDeleteJob = new DeleteJob(mPopSession);
+            mDeleteJob->setDeleteIds(mIdsWaitingToDelete);
+            mIdsWaitingToDelete.clear();
+            connect(mDeleteJob, &DeleteJob::result, this, &POP3Resource::deleteJobResult);
+            mDeleteJob->start();
+        }
+    } else {
+        advanceState(Save);
     }
 }
 
@@ -456,7 +477,7 @@ void POP3Resource::targetCollectionFetchJobFinished(KJob *job)
     }
     mTestLocalInbox = false;
     Akonadi::CollectionFetchJob *fetchJob =
-        dynamic_cast<Akonadi::CollectionFetchJob *>(job);
+        qobject_cast<Akonadi::CollectionFetchJob *>(job);
     Q_ASSERT(fetchJob);
     Q_ASSERT(fetchJob->collections().size() <= 1);
 
@@ -500,10 +521,10 @@ void POP3Resource::listJobResult(KJob *job)
         cancelSync(i18n("Error while getting the list of messages on the server.") +
                    QLatin1Char('\n') + job->errorString());
     } else {
-        ListJob *listJob = dynamic_cast<ListJob *>(job);
+        ListJob *listJob = qobject_cast<ListJob *>(job);
         Q_ASSERT(listJob);
         mIdsToSizeMap = listJob->idList();
-        idsToSaveValid = false;
+        mIdsToSaveValid = false;
         qCDebug(POP3RESOURCE_LOG) << "IdsToSizeMap:" << mIdsToSizeMap;
         advanceState(UIDList);
     }
@@ -515,7 +536,7 @@ void POP3Resource::uidListJobResult(KJob *job)
         cancelSync(i18n("Error while getting list of unique mail identifiers from the server.") +
                    QLatin1Char('\n') + job->errorString());
     } else {
-        UIDListJob *listJob = dynamic_cast<UIDListJob *>(job);
+        UIDListJob *listJob = qobject_cast<UIDListJob *>(job);
         Q_ASSERT(listJob);
         mIdsToUidsMap = listJob->uidList();
         mUidsToIdsMap = listJob->idList();
@@ -639,8 +660,9 @@ void POP3Resource::itemCreateJobResult(KJob *job)
     //qCDebug(POP3RESOURCE_LOG) << "Just stored message with ID" << idOfMessageJustCreated
     //         << "on the Akonadi server";
 
-    if (shouldDeleteId(idOfMessageJustCreated)) {
-        mIdsWaitingToDelete << idOfMessageJustCreated;
+    const QList<int> idToDeleteMessage = shouldDeleteId(idOfMessageJustCreated);
+    if (!idToDeleteMessage.isEmpty()) {
+        mIdsWaitingToDelete << idToDeleteMessage;
         if (!mDeleteJob) {
             mDeleteJob = new DeleteJob(mPopSession);
             mDeleteJob->setDeleteIds(mIdsWaitingToDelete);
@@ -668,12 +690,12 @@ int POP3Resource::idToTime(int id) const
 
     // If we don't find any mail, either we have no UID, or it is not in the seen UID
     // list. In that case, we assume that the mail is new, i.e. from now
-    return time(Q_NULLPTR);
+    return time(0);
 }
 
 int POP3Resource::idOfOldestMessage(const QSet<int> &idList) const
 {
-    int timeOfOldestMessage = time(Q_NULLPTR) + 999;
+    int timeOfOldestMessage = time(0) + 999;
     int idOfOldestMessage = -1;
     foreach (int id, idList) {
         const int idTime = idToTime(id);
@@ -686,26 +708,28 @@ int POP3Resource::idOfOldestMessage(const QSet<int> &idList) const
     return idOfOldestMessage;
 }
 
-bool POP3Resource::shouldDeleteId(int downloadedId) const
+QList<int> POP3Resource::shouldDeleteId(int downloadedId) const
 {
+    QList<int> idsToDeleteFromServer;
     // By default, we delete all messages. But if we have "leave on server"
     // rules, we can save some messages.
     if (Settings::self()->leaveOnServer()) {
-        if (!idsToSaveValid) {
-            idsToSaveValid = true;
-            idsToSave = QSet<int>();
+        idsToDeleteFromServer = mIdsToSizeMap.keys();
+        if (!mIdsToSaveValid) {
+            mIdsToSaveValid = true;
+            mIdsToSave.clear();
 
-            const QSet<int> idsOnServer = QSet<int>::fromList(mIdsToSizeMap.keys());
+            const QSet<int> idsOnServer = QSet<int>::fromList(idsToDeleteFromServer);
 
             // If the time-limited leave rule is checked, add the newer messages to
             // the list of messages to keep
             if (Settings::self()->leaveOnServerDays() > 0) {
                 const int secondsPerDay = 86400;
-                time_t timeLimit = time(Q_NULLPTR) - (secondsPerDay * Settings::self()->leaveOnServerDays());
+                time_t timeLimit = time(0) - (secondsPerDay * Settings::self()->leaveOnServerDays());
                 foreach (int idToDelete, idsOnServer) {
                     const int msgTime = idToTime(idToDelete);
                     if (msgTime >= timeLimit) {
-                        idsToSave << idToDelete;
+                        mIdsToSave << idToDelete;
                     } else {
                         qCDebug(POP3RESOURCE_LOG) << "Message" << idToDelete << "is too old and will be deleted.";
                     }
@@ -716,21 +740,21 @@ bool POP3Resource::shouldDeleteId(int downloadedId) const
             // be reduced in the following number-limited leave rule and size-limited
             // leave rule checks
             else {
-                idsToSave = idsOnServer;
+                mIdsToSave = idsOnServer;
             }
 
             //
             // Delete more old messages if there are more than mLeaveOnServerCount
             //
             if (Settings::self()->leaveOnServerCount() > 0) {
-                const int numToDelete = idsToSave.count() - Settings::self()->leaveOnServerCount();
-                if (numToDelete > 0 && numToDelete < idsToSave.count()) {
+                const int numToDelete = mIdsToSave.count() - Settings::self()->leaveOnServerCount();
+                if (numToDelete > 0 && numToDelete < mIdsToSave.count()) {
                     // Get rid of the first numToDelete messages
                     for (int i = 0; i < numToDelete; i++) {
-                        idsToSave.remove(idOfOldestMessage(idsToSave));
+                        mIdsToSave.remove(idOfOldestMessage(mIdsToSave));
                     }
-                } else if (numToDelete >= idsToSave.count()) {
-                    idsToSave.clear();
+                } else if (numToDelete >= mIdsToSave.count()) {
+                    mIdsToSave.clear();
                 }
             }
 
@@ -740,21 +764,30 @@ bool POP3Resource::shouldDeleteId(int downloadedId) const
             if (Settings::self()->leaveOnServerSize() > 0) {
                 const qint64 limitInBytes = Settings::self()->leaveOnServerSize() * (1024 * 1024);
                 qint64 sizeOnServerAfterDeletion = 0;
-                foreach (int id, idsToSave) {
+                foreach (int id, mIdsToSave) {
                     sizeOnServerAfterDeletion += mIdsToSizeMap.value(id);
                 }
                 while (sizeOnServerAfterDeletion > limitInBytes) {
-                    int oldestId = idOfOldestMessage(idsToSave);
-                    idsToSave.remove(oldestId);
+                    int oldestId = idOfOldestMessage(mIdsToSave);
+                    mIdsToSave.remove(oldestId);
                     sizeOnServerAfterDeletion -= mIdsToSizeMap.value(oldestId);
                 }
             }
         }
-
-        return !idsToSave.contains(downloadedId);
+        // Now save the messages from deletion
+        //
+        foreach (int idToSave, mIdsToSave) {
+            idsToDeleteFromServer.removeAll(idToSave);
+        }
+        if (downloadedId != -1 && !mIdsToSave.contains(downloadedId)) {
+            idsToDeleteFromServer << downloadedId;
+        }
+    } else {
+        if (downloadedId != -1) {
+            idsToDeleteFromServer << downloadedId;
+        }
     }
-
-    return true;
+    return idsToDeleteFromServer;
 }
 
 void POP3Resource::deleteJobResult(KJob *job)
@@ -776,7 +809,7 @@ void POP3Resource::deleteJobResult(KJob *job)
     QList<int> timeOfSeenUids = Settings::self()->seenUidTimeList();
     Q_ASSERT(seenUIDs.size() == timeOfSeenUids.size());
     foreach (int deletedId, mDeletedIDs) {
-        QString deletedUID = mIdsToUidsMap.value(deletedId);
+        const QString deletedUID = mIdsToUidsMap.value(deletedId);
         if (!deletedUID.isEmpty()) {
             int index = seenUIDs.indexOf(deletedUID);
             if (index != -1) {
@@ -860,7 +893,7 @@ void POP3Resource::saveSeenUIDList()
     }
     QList<QString> uidsOfMessagesDownloadedButNotDeleted;
     foreach (int id, idsOfMessagesDownloadedButNotDeleted) {
-        QString uid = mIdsToUidsMap.value(id);
+        const QString uid = mIdsToUidsMap.value(id);
         if (!uid.isEmpty()) {
             uidsOfMessagesDownloadedButNotDeleted.append(uid);
         }
@@ -869,7 +902,7 @@ void POP3Resource::saveSeenUIDList()
     foreach (const QString &uid, uidsOfMessagesDownloadedButNotDeleted) {
         if (!seenUIDs.contains(uid)) {
             seenUIDs.append(uid);
-            timeOfSeenUIDs.append(time(Q_NULLPTR));
+            timeOfSeenUIDs.append(time(0));
         }
     }
 
