@@ -24,7 +24,7 @@
 #include <QJsonDocument>
 #include <QJsonObject>
 
-TomboyItemsDownloadJob::TomboyItemsDownloadJob(const Akonadi::Collection::Id &id, KIO::AccessManager *manager, QObject *parent)
+TomboyItemsDownloadJob::TomboyItemsDownloadJob(Akonadi::Collection::Id id, KIO::AccessManager *manager, QObject *parent)
     : TomboyJobBase(manager, parent),
       mCollectionId(id)
 {
